/*
 * SPDX-FileCopyrightText: 2024-2025 Bruno Anselme <be.root@gfree.fr>
 *
 * Authors:
 *   Bruno Anselme <be.root@gfree.fr>
 *
 *   SPDX-License-Identifier: GPL-3.0-or-later
 *
 * This file is part of the NoComprendo software.
*/

/**
 * @file      aboutdialog.cpp
 * @author    Bruno ANSELME
 * @brief     AboutDialog class definition
 * @details   Display informations and help.
 */

#include <QDir>
#include <QSettings>
#include "about.h"
#include "app_version.h"

//---------------------------
AboutDialog::AboutDialog(QString &lang, QWidget *parent) : QDialog(parent)
{
    ui.setupUi(this);
    setWindowTitle(tr("About %1").arg(APP_NAME));
    connect(ui.btHelp,          SIGNAL(clicked()), this, SLOT(showHelp()));
    connect(ui.btUsage,         SIGNAL(clicked()), this, SLOT(showUsage()));
    connect(ui.btCommands,      SIGNAL(clicked()), this, SLOT(showCommands()));
    connect(ui.btSettings,      SIGNAL(clicked()), this, SLOT(showSettings()));
    connect(ui.btCredits,       SIGNAL(clicked()), this, SLOT(showCredits()));
    connect(ui.btLicense,       SIGNAL(clicked()), this, SLOT(showLicense()));
    connect(ui.btAboutQt,       SIGNAL(clicked()), qApp, SLOT(aboutQt()));
    locale = lang.left(2);
    QDir dir(QString(":/help/%1").arg(locale));
    if (!dir.exists()) locale = "en";
    ui.lbTitle->setText(QString("%1 - %2").arg(APP_NAME).arg(APP_VERSION));
    // emit ui.btHelp->click();
    QSettings settings(APP_ORG, APP_NAME);
    move(settings.value("helpPos", QPoint(150, 250)).toPoint());
    resize(settings.value("helpSize", QSize(818, 600)).toSize());
    defPage = settings.value("helpPage", "about").toString();
    if (defPage == "about")         // Restore previous opened help page
        emit ui.btHelp->click();
    else  if (defPage == "usage")
        emit ui.btUsage->click();
    else  if (defPage == "commands")
        emit ui.btCommands->click();
    else  if (defPage == "settings")
        emit ui.btSettings->click();
    else  if (defPage == "credits")
        emit ui.btCredits->click();
    else  if (defPage == "credits")
        emit ui.btCredits->click();
    else  if (defPage == "license")
        emit ui.btCredits->click();
    showPage(defPage);
}

AboutDialog::~AboutDialog() {
    QSettings settings(APP_ORG, APP_NAME);
    settings.setValue("helpPos",            pos());
    settings.setValue("helpSize",           size());
    settings.setValue("helpPage", defPage);
}

void AboutDialog::showPage(QString page)
{
    defPage = page;
    QFile file(QString(":/help/%1/%2.html").arg(locale).arg(page));
    if (!file.open(QIODevice::ReadOnly | QIODevice::Text))
            return;
    ui.tbHtml->setText(QString::fromUtf8(file.readAll()));
    file.close();
}

void AboutDialog::showLicense()
{
    defPage = "license";
    QFile file(QString(":/help/license-gpl-3.0.html"));
    if (!file.open(QIODevice::ReadOnly | QIODevice::Text))
            return;
    ui.tbHtml->setText(QString::fromUtf8(file.readAll()));
    file.close();
}

