/*
 * SPDX-FileCopyrightText: 2024-2025 Bruno Anselme <be.root@gfree.fr>
 *
 * Authors:
 *   Bruno Anselme <be.root@gfree.fr>
 *
 *   SPDX-License-Identifier: GPL-3.0-or-later
 *
 * This file is part of the NoComprendo software.
*/

#ifndef COMMANDSET_H
#define COMMANDSET_H

#include <QTableWidget>
#include "command.h"

#define COL_UTTERANCE   0
#define COL_TYPE        1
#define COL_COMMAND     2

class CommandSet : public QObject {
    Q_OBJECT
public:
    enum        ShortcutFormat { QtShortcut, XdoShortcut };                         // Qt format or KeySym format
public:
    explicit    CommandSet(QString fname);                                          //!< Create command set from file name
    QString     getCommandsUtterance();                                             //!< Return commands utterances for language model
    QString     getCommandsCSV();                                                   //!< Return commands utterances and action for CSV
    QString     getName()                                   { return name; }        //!< Return commands set name
    const       QMap<QString, Command *> *getCommands()     { return &commands; }   //!< Return commands table
    void        fillTable(QTableWidget *table, CommandSet::ShortcutFormat format);  //!< Fill GUI table with commands names and actions
public Q_SLOTS:
    void        loadCommands();                                                     //!< Load from file. This file is created from GUI by EditSet::accept()
private:
    QString                     filename;                                           // Commands set file name
    QString                     name;                                               // Commands set name
    QMap<QString, Command *>    commands;                                           // QString is the utterance linked to a command pointer
};

#endif // COMMANDSET_H
