/*
 * SPDX-FileCopyrightText: 2024-2025 Bruno Anselme <be.root@gfree.fr>
 *
 * Authors:
 *   Bruno Anselme <be.root@gfree.fr>
 *
 *   SPDX-License-Identifier: GPL-3.0-or-later
 *
 * This file is part of the NoComprendo software.
*/

#ifndef DOTOOLPIPE_H
#define DOTOOLPIPE_H

#include <QObject>
#include <QProcess>
#include "command.h"

// Launch piped dotool. Send commands to simulate mouse and keyboard.

class DoToolPipe : public QObject {
    Q_OBJECT
public:
    explicit DoToolPipe(QString &kbdVariant);
    ~DoToolPipe();

    void writePipe(QString);
    void sendSequence(QString seq);
    void mouseAction(Command::mouseType, int count = 1);
    void mouseTo(float x, float y);
    void setSteps(int moveStep_, int glideStep_, int wheelStep_);
    void setDelays(int keyDelay, int keyHold, int typeDelay, int typeHold);
private Q_SLOTS:
    void doToolError();
Q_SIGNALS:

private:
    QString program;
    QProcess myProcess;
    int moveStep, glideStep, wheelStep;
    int errorCount;
};

#endif // DOTOOLPIPE_H
