/*
 * SPDX-FileCopyrightText: 2024-2025 Bruno Anselme <be.root@gfree.fr>
 *
 * Authors:
 *   Bruno Anselme <be.root@gfree.fr>
 *
 *   SPDX-License-Identifier: GPL-3.0-or-later
 *
 * This file is part of the NoComprendo software.
*/

#ifndef EDITSHORTCUT_H
#define EDITSHORTCUT_H

#include <QDialog>
#include <QButtonGroup>

#include "commandset.h"
#include "ui_editcommand.h"
#include "vosk_api.h"
#include "comprendo.h"

namespace Ui {
    class dialCommand;
}

class EditCommand : public QDialog {
    Q_OBJECT
public:
    explicit    EditCommand(QString utt, Command &cmd, Comprendo *what_);         //!< Constructor
    ~EditCommand();
    QKeySequence        getSequence();                          //!< Return current key sequence
    QString             getText();                              //!< Return current text
    Command::comType    getType();                              //!< Return current command type
    Command::metaType   getMeta();                              //!< Return current meta command type
    Command::mouseType  getMouse();                             //!< Return current mouse command type
    QString             getExec();                              //!< Return current exec command text
    QString             getUtterance() { return ui->leUtterance->text(); }
protected:
    void    timerEvent(QTimerEvent *) override;
private Q_SLOTS:
    void    toMeta();                                   //!< Switch GUI to meta type
    void    toKey();                                    //!< Switch GUI to key sequence type
    void    toMouse();                                  //!< Switch GUI to mouse type
    void    toText();                                   //!< Switch GUI to text input type
    void    toExec();                                   //!< Switch GUI to exec type
    void    checkSequence(const QString &s);            //!< Check for valid key sequence
    void    checkExec();                                //!< Check for valid execution command
    void    newKeySequence();                           //!< Read new key sequence from GUI
    void    startRecording();                           //!< Star recording utterance from microphone
    void    browseExecutable();                         //!< Open get file dialog for executables files
    void    checkAccept();
    void    currentMetaChanged();
private:
    void    initUi();
    void    clearSignals(Command::comType newtype);     //!< Clear connected signal when command type changes
private:
    Ui::dialCommand    *ui;
    QButtonGroup        buts;
    Command::comType    lastType;
    Comprendo          *what;
};

#endif // EDITSHORTCUT_H
