/*
 * SPDX-FileCopyrightText: 2024-2025 Bruno Anselme <be.root@gfree.fr>
 *
 * Authors:
 *   Bruno Anselme <be.root@gfree.fr>
 *
 *   SPDX-License-Identifier: GPL-3.0-or-later
 *
 * This file is part of the NoComprendo software.
*/

#include "app_version.h"
#include "editutterance.h"
#include "ui_editutterance.h"

EditUtterance::EditUtterance(QString title, QString utt, Comprendo *what_) :
    QDialog(),
    ui(new Ui::dialUtterance)
{
    what = what_;

    ui->setupUi(this);
    ui->lbUtterance->setText(ui->lbUtterance->text().arg(title));
    ui->leUtterance->setText(utt);

    QSettings settings(APP_ORG, APP_NAME);
    move(settings.value("uttPos", QPoint(200, 300)).toPoint());
    resize(settings.value("uttSize", QSize(467, 100)).toSize());

    connect(ui->btRecord, SIGNAL(clicked()), this, SLOT(startRecording()));
    connect(ui->btOk,     SIGNAL(clicked()), this, SLOT(checkAccept()));
    startTimer(250);
    ui->lbUtteranceStatus->setStyleSheet("QLabel { color : red; }");
}

EditUtterance::~EditUtterance()
{
    QSettings settings(APP_ORG, APP_NAME);
    settings.setValue("uttPos",    pos());
    settings.setValue("uttSize",   size());
    delete ui;
}

void EditUtterance::checkAccept() {
    if (!ui->leUtterance->text().trimmed().isEmpty())
        accept();
    else
        ui->lbUtteranceStatus->setText(tr("Empty utterance"));
}

void EditUtterance::timerEvent(QTimerEvent *) {
    if (what->isListening()) {
        QString *utt = what->recognize_from_microphone();
        Comprendo::VoskStatus status = what->getStatus();
        switch(status) {
        case Comprendo::VoskStatus::Partial :
            ui->leUtterance->setText(*utt);
            break;
        case Comprendo::VoskStatus::Final :
            ui->leUtterance->setEnabled(true);
            ui->leUtterance->setText(*utt);
            what->listen(false);
            ui->btRecord->setEnabled(true);
            break;
        case Comprendo::VoskStatus::Empty :
            break;
        }
        delete utt;
    }
}

void EditUtterance::startRecording() {
    ui->btRecord->setEnabled(false);
    ui->leUtterance->setEnabled(false);
    ui->leUtterance->setText(tr("Recording an utterance"));
    what->listen(true);
}


void EditUtterance::changeEvent(QEvent *e)
{
    QWidget::changeEvent(e);
    switch (e->type()) {
    case QEvent::LanguageChange:
        ui->retranslateUi(this);
        break;
    default:
        break;
    }
}
