/*
 * SPDX-FileCopyrightText: 2024-2025 Bruno Anselme <be.root@gfree.fr>
 *
 * Authors:
 *   Bruno Anselme <be.root@gfree.fr>
 *
 *   SPDX-License-Identifier: GPL-3.0-or-later
 *
 * This file is part of the NoComprendo software.
*/

/**
 * @file      modelchooser.cpp
 * @author    Bruno ANSELME
 * @brief     ModelChooser class definition
 * @details   Select language from available acoustics models.
 */

#include <QDir>
#include "app_version.h"
#include "modelchooser.h"
#include "modelloader.h"

ModelChooser::ModelChooser() : QDialog()
{
    ui.setupUi(this);
    updateModelList();
    connect(ui.btLoadModel, SIGNAL(clicked(bool)), this, SLOT(loadModel()));
}

void ModelChooser::updateModelList() {
    ui.cbModel->clear();
    QVariant path;
    QStringList filter = { "vosk-model-*" };
    QStringList files = APPCONF.voskSystemPath.entryList(filter, QDir::Dirs);   // Load availables models in system path
    int i = 0;
    for (; i < files.count(); i++) {
        ui.cbModel->addItem(QString("%1").arg(files[i]), APPCONF.voskSystemPath.path());
    }
    files += APPCONF.voskUserPath.entryList(filter);                // Add availables models in user path
    for (;i < files.count(); i++) {
        ui.cbModel->addItem(QString("%1").arg(files[i]), APPCONF.voskUserPath.path());
    }
    ui.lbTitle->setText(tr("Choose model"));
    ui.lbMessage->setText(tr("You system language is <b>%1/%2</b> : %3")
        .arg(QLocale::system().nativeLanguageName())
        .arg(QLocale::system().nativeTerritoryName())
        .arg(QLocale::system().name()));
    for (int j=0; j < files.count(); j++) {                     // auto select default language if present
        if (files[j] == APPCONF.model)
            ui.cbModel->setCurrentIndex(j);
    }
}

QString ModelChooser::getModel() {
    return ui.cbModel->currentData().toString() + "/" + ui.cbModel->currentText();
}

void ModelChooser::loadModel() {
    ModelLoader dial;
    dial.exec();
    updateModelList();
}
