/*
 * SPDX-FileCopyrightText: 2024-2025 Bruno Anselme <be.root@gfree.fr>
 *
 * Authors:
 *   Bruno Anselme <be.root@gfree.fr>
 *
 *   SPDX-License-Identifier: GPL-3.0-or-later
 *
 * This file is part of the NoComprendo software.
*/

#ifndef OSD_H
#define OSD_H

#include <QFrame>
#include <QLabel>
#include <QTimer>
#include "config.h"
#include "ui_osd.h"

namespace Ui {
    class OSD;
}

class OSDWindow : public QFrame
{
    Q_OBJECT
public:
    explicit    OSDWindow();                                //!< Constructor
    void        setText(QString s);                         //!< Set OSD text
    void        setFlashingText(QString s);                 //!< Set OSD text with limited time life
    void        setUnknown(QString s);                      //!< Set OSD colored text (unknown utterance)
    void        setItalic(QString s);                       //!< Set OSD italic text (dictation)
    void        changeOsd(QPoint pos, QSize siz);           //!< Change OSD window position
    QPoint      getPosition()       { return pos();     }   //!< Get OSD window position (used by OSDEditor)
    QSize       getSize()           { return size();    }   //!< Get OSD window size (used by OSDEditor)
protected:
    void        paintEvent(QPaintEvent *event);             //!< Draw OSD window
protected Q_SLOTS:
    void        endTimer();                                 //!< Hide OSD window
    void        mouseMoveEvent(QMouseEvent *event);         //!< Drag OSD window (used by OSDEditor)
    void        mousePressEvent(QMouseEvent *event);        //!< Start dragging OSD window  (used by OSDEditor)
private:
    Ui::OSD    *ui;
    QLabel      message;
    QTimer      timer;
    QPoint      offset;         // Offset while moving
    QRect       handle;         // Handle for resizing
    bool        resizing;       // Moving if not resizing
    QRect       rscreens;
    int         fontSize;
};

#endif // OSD_H
