/*
 * SPDX-FileCopyrightText: 2024-2025 Bruno Anselme <be.root@gfree.fr>
 *
 * Authors:
 *   Bruno Anselme <be.root@gfree.fr>
 *
 *   SPDX-License-Identifier: GPL-3.0-or-later
 *
 * This file is part of the NoComprendo software.
*/

/**
 * @file      reminder.cpp
 * @author    Bruno ANSELME
 * @brief     Reminder class definition
 * @details   Full screen window for commands reminder.
 */

#include <QCoreApplication>
#include <QGridLayout>

#include "config.h"
#include "reminder.h"

Reminder::Reminder(Comprendo *comp) : QDialog()
{
    what    = comp;
    setWindowFlags(Qt::WindowStaysOnTopHint | Qt::FramelessWindowHint );
    QGridLayout *layout = new QGridLayout(this);
    QListWidget *list = new QListWidget;
    layout->addWidget(list);
    QFont f = list->font();
    f.setPixelSize(APPCONF.rFontSize);
    list->setFont(f);
    list->setWrapping(true);
    list->setResizeMode(QListView::Adjust);
    list->addItems(comp->getCommandsList().split("\n"));
    list->setEnabled(false);
    QPalette palette = list->palette();
    palette.setColor(QPalette::Disabled, QPalette::Text, Qt::black);            // highlight disabled palette
    if (APPCONF.rInvertColor) {
        palette.setColor(QPalette::Disabled, QPalette::Text, Qt::white);        // invert colors
        palette.setColor(QPalette::Disabled, QPalette::Base, Qt::black);
    }
    list->setPalette(palette);
    Command    *com;
    QList<QListWidgetItem *> titles = list->findItems(QString("*"), Qt::MatchWildcard);
    for (int i = 0; i < titles.count(); i++) {
        if (titles[i]->text().contains(QRegularExpression("^-- "))) {                      // Commands set name
            titles[i]->setBackground(Qt::gray);
            titles[i]->setText(titles[i]->text().replace("-- ",""));
        } else {
            int count = 1;
            com = what->getCommand(titles[i]->text(), count);
            if (com)
                titles[i]->setToolTip(com->getQtKey());
        }
    }
    showFullScreen();
}

void Reminder::changeEvent(QEvent *event) {         // Close dialog if focus is lost
    if (event->type() == QEvent::ActivationChange)
        if (!this->isActiveWindow())
            emit reject();
}

void Reminder::mousePressEvent(QMouseEvent *) {     // Close dialog on any mouse event
    emit reject();
}

void Reminder::keyPressEvent(QKeyEvent *) {         // Close dialog on any key event
    emit reject();
}
