/*
 * SPDX-FileCopyrightText: 2024-2025 Bruno Anselme <be.root@gfree.fr>
 *
 * Authors:
 *   Bruno Anselme <be.root@gfree.fr>
 *
 *   SPDX-License-Identifier: GPL-3.0-or-later
 *
 * This file is part of the NoComprendo software.
*/

#ifndef SETTINGS_H
#define SETTINGS_H

#include <QDialog>
#include <QListWidget>
#include <QToolButton>
#include "config.h"
#include "ui_settings.h"
#include "comprendo.h"

namespace Ui {
class NCSettings;
}

class Settings : public QDialog {
    Q_OBJECT
public:
    explicit    Settings(Comprendo *what_);                     //!< Constructor. Initialize dialog's fields
    ~Settings();
public Q_SLOTS:
    void        accept();                                       //!< Copy and save dialog's fields into Config
    void        moveOsd();                                      //!< Change OSD position. Use OSDEditor.
    void        addMultiplier();
    void        removeLastMultiplier();
    void        speechLangChanged(int);
Q_SIGNALS:
    void        sendInformation(const QString &);               //!< Send text to be shown in an information window by MainWindow
    void        resetDefaultSets();
protected Q_SLOTS:
    void        changeMouseLine(int, int, int, int);            //!< Change line for mouse MoveTo.
    void        editMouseUtterance(int row, int column);        //!< Edit utterances for mouse MoveTo. Use UtteranceBuilder
    void        editRepeaterUtterance(int row, int column);     //!< Edit utterances for mouse MoveTo. Use UtteranceBuilder
    void        sendResetSets();
    void        loadModel();
    void        numpadGridChanged(bool);
    void        restoreDelays();
private:
    void        updateModelList();
    void        initGrid();
private:
    Ui::NCSettings     *ui;
    Comprendo          *what;
    QPoint              osdPosition;
    QSize               osdSize;
    QList<QToolButton*> recButton;
    QMap<int, int>      numPadMap;
};

#endif // SETTINGS_H
