/*
 * SPDX-FileCopyrightText: 2024-2025 Bruno Anselme <be.root@gfree.fr>
 *
 * Authors:
 *   Bruno Anselme <be.root@gfree.fr>
 *
 *   SPDX-License-Identifier: GPL-3.0-or-later
 *
 * This file is part of the NoComprendo software.
*/

#include <QRegularExpression>
#include <QStandardPaths>

#include "app_version.h"
#include "speech.h"
#include "config.h"

Speech::Speech(QObject *parent)
    : QThread{parent}
{
    pipeFile = QString("%1/%2-%3-pipe.wav").arg(QStandardPaths::writableLocation(QStandardPaths::TempLocation)).arg(APP_STR).arg(qgetenv("USER"));
    QProcess    aProcess;
    aProcess.setProgram("/bin/bash");
    aProcess.setArguments({  "-c", "ln -s /dev/stdout " + pipeFile });  // Create a pseudo wave file where pico2wave writes
    aProcess.start();
    aProcess.waitForFinished();
}

Speech::~Speech() {
    QProcess    aProcess;
    aProcess.setProgram("/bin/bash");
    aProcess.setArguments({  "-c", "rm -f " + pipeFile });              // Remove pseudo wave file.
    aProcess.start();
    aProcess.waitForFinished();
}

void Speech::setSpeech(QString text) {
    aSpeech = text;
}

void Speech::getSpeechesList() {
    APPCONF.speechesList.clear();
    QStringList filter = { "*ta.bin" };
    QStringList files = APPCONF.speechDir.entryList(filter);
    QRegularExpression re("(.*)_ta.bin");
    for (int k = 0; k < files.count(); k++) {
        files[k] = files[k].replace(re, "\\1");
        QLocale     loco(files[k]);
        APPCONF.speechesList[files[k]] = loco.nativeTerritoryName();
    }
}

void Speech::run() {
    setTerminationEnabled(true);
    // Prepare arguments for text to speech
    QProcess aProcess;
    aProcess.setProgram("/bin/bash");
    aProcess.setArguments({ "-c", "pico2wave -w " + pipeFile + " -l " + APPCONF.speechLang + " | sox  -t wav - -t wav - tempo 0.90  | play -t wav -" });
    aProcess.setProcessChannelMode(QProcess::ForwardedOutputChannel);
    connect(this, SIGNAL(abortSpeech()), &aProcess, SLOT(terminate()));
    aProcess.start(QIODeviceBase::Unbuffered | QIODeviceBase::ReadWrite);
    aProcess.write(aSpeech.toStdString().c_str());
    aProcess.closeWriteChannel();
    aProcess.waitForFinished(-1);
    aProcess.close();
    emit speechFinished();
}

void Speech::stopSpeech() {
    emit abortSpeech();     // terminate speech process
    terminate();            // terminate running thread
    wait();
    emit speechFinished();
}
