/*
 * SPDX-FileCopyrightText: 2024-2025 Bruno Anselme <be.root@gfree.fr>
 *
 * Authors:
 *   Bruno Anselme <be.root@gfree.fr>
 *
 *   SPDX-License-Identifier: GPL-3.0-or-later
 *
 * This file is part of the NoComprendo software.
*/

#ifndef TRAYICON_H
#define TRAYICON_H

#include <QMenu>
#include <QSystemTrayIcon>
#include "config.h"

class TrayIcon : public QSystemTrayIcon {
    Q_OBJECT
public:
    enum    Status     { Stopped,  Ready, Listening,  Suspended, ListenSuspend, Dictation, ListenDictation, Speak };
public:
    TrayIcon();                                                 //!< Constructor. Prepare icons, messages, actions
    void            setStatus(Status s);                        //!< Set icon and tooltip
    void            setMenus(bool running, bool suspended);     //!< Enable/disable tray icon menus
    void            setDictationChecked(bool);
    void            setTheme(QString themeDir_);
public Q_SLOTS:
    void            sendDictation();                            //!< Send trayDictation signal
    void            sendSpeak();                                //!< Send traySpeak signal
    void            sendStart();                                //!< Send trayStart signal
    void            sendStop();                                 //!< Send trayStop signal
    void            sendSuspend();                              //!< Send traySuspend signal
    void            sendQuit();                                 //!< Send trayQuit signal
    void            sendShow();                                 //!< Send trayShow signal
Q_SIGNALS:
    void            trayDictation();                            //!< Start/stop signal sent to MainWindow
    void            traySpeak();                                //!< Send signal to start text to speech
    void            trayStart();                                //!< Start signal sent to MainWindow
    void            trayStop();                                 //!< Stop signal sent to MainWindow
    void            traySuspend();                              //!< Suspend signal sent to MainWindow
    void            trayQuit();                                 //!< Quit signal sent to MainWindow
    void            trayShow();                                 //!< Show signal sent to MainWindow
private:
    QMenu                   myMenu;
    QMap<Status, QIcon>     icons;
    QMap<Status, QString>   messages;
    QMap<Status, QAction *> actions;
    Status                  trayStatus;
    QString                 themeDir;
};

#endif // TRAYICON_H
