/*
 * SPDX-FileCopyrightText: 2024-2025 Bruno Anselme <be.root@gfree.fr>
 *
 * Authors:
 *   Bruno Anselme <be.root@gfree.fr>
 *
 *   SPDX-License-Identifier: GPL-3.0-or-later
 *
 * This file is part of the NoComprendo software.
*/

#ifndef ZOOMBUTTON_H
#define ZOOMBUTTON_H

#include <QList>
#include <QAbstractButton>
#include <QPointF>
#include "comprendo.h"

// Special button class for Mouse MoveTo command. Based on keypads numbers.
class ZoomButton : public QAbstractButton
{
    Q_OBJECT
public:
    ZoomButton(Comprendo *comp = nullptr);            //!< Constructor
    ~ZoomButton();
    void            exec();                                             //!< Run event lopp
    bool            hasClicked()            { return done;      }       //!< True if zoom selection completed
    QPoint          where()                 { return here;      }       //!< Final mouse position
    QPointF         whereRatio();
    virtual bool    eventFilter(QObject *obj, QEvent *event) override;  //!< Watch for focus lost

    static QStringList  readMouseFileList();
    static void         createMouseFile();

Q_SIGNALS:
    void            zoomClicked();                                      //!< Sent to stop execution loop
    void            focusLost(bool in);                                 //!< Sent if window is desactivated
protected:
    void            timerEvent(QTimerEvent *event) override;            //!< Trigerred when an utterance is received
    void            paintEvent(QPaintEvent *) override;                 //!< Draw 9 boxes and call subboxes.
    void            keyReleaseEvent(QKeyEvent *e) override;             //!< Keys 1 to 9 can be used instead of voice command
    void            resizeEvent(QResizeEvent *e) override;              //!< Resized once when created
    void            drawGrid(QRect r, QPainter *painter, int level);    //!< Draw 9 boxes
    const QRect     rectNumber(QRect r, int num);                       //!< Get rectangle of last selected boxe
    void            pushFrame(Qt::Key);                                 //!< Stack frames (boxes)
    void            popFrame();                                         //!< Unstack frames
    void            readMouseFile();
private:
    Comprendo              *what;
    QList<QRect>            frames;
    QHash<QString, Qt::Key> boxes;
    bool                    done;
    QPoint                  here;
    int                     timerid;
    QRectF                  screen;
    QPoint                  offset;
    QList<Qt::Key>          boxKeys;
};

#endif // ZOOMBUTTON_H
